pub struct PyFeeModel;Trait Implementations
Sourceimpl Debug for PyFeeModel
impl Debug for PyFeeModel
impl DerefToPyAny for PyFeeModel
impl ExtractPyClassWithClone for PyFeeModel
Sourceimpl<'py> IntoPyObject<'py> for PyFeeModel
impl<'py> IntoPyObject<'py> for PyFeeModel
Sourcetype Target = PyFeeModel
type Target = PyFeeModel
The Python output type
Sourcetype Output = Bound<'py, <PyFeeModel as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyFeeModel as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyFeeModel
impl PyClass for PyFeeModel
Sourceimpl PyClassBaseType for PyFeeModel
impl PyClassBaseType for PyFeeModel
type LayoutAsBase = <PyFeeModel as PyClassImpl>::Layout
type BaseNativeType = <PyFeeModel as PyClassImpl>::BaseNativeType
type Initializer = PyClassInitializer<PyFeeModel>
type PyClassMutability = <PyFeeModel as PyClassImpl>::PyClassMutability
Sourcetype Layout<T: PyClassImpl> = <<PyFeeModel as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
type Layout<T: PyClassImpl> = <<PyFeeModel as PyClassBaseType>::BaseNativeType as PyClassBaseType>::Layout<T>
The type of object layout to use for ancestors or descendants of this type.
Sourceimpl PyClassImpl for PyFeeModel
impl PyClassImpl for PyFeeModel
Sourceconst IS_BASETYPE: bool = true
const IS_BASETYPE: bool = true
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyFeeModel as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyFeeModel>
type Layout = <<PyFeeModel as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyFeeModel>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = ThreadCheckerImpl
type ThreadChecker = ThreadCheckerImpl
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForPyFeeModel
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for PyFeeModel
impl PyClassNewTextSignature for PyFeeModel
const TEXT_SIGNATURE: &'static str = "(*_args, **_kwargs)"
Sourceimpl PyStubType for PyFeeModel
impl PyStubType for PyFeeModel
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
fn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for PyFeeModel
impl PyTypeInfo for PyFeeModel
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Auto Trait Implementations
impl Freeze for PyFeeModel
impl RefUnwindSafe for PyFeeModel
impl Send for PyFeeModel
impl Sync for PyFeeModel
impl Unpin for PyFeeModel
impl UnsafeUnpin for PyFeeModel
impl UnwindSafe for PyFeeModel