pyobject_to_fee_model_any

Function pyobject_to_fee_model_any 

pub fn pyobject_to_fee_model_any(
    obj: &Bound<'_, PyAny>,
) -> PyResult<FeeModelAny>
Extracts a Python fee model object into a Rust FeeModelAny.

Errors

Returns an error if obj is not a supported fee model binding.